@@ -7,8 +7,8 @@ See also:
 
 - [Documentation](https://tropos-rsd.github.io/earthcarekit/)
 - [Development status (GitHub)](https://github.com/TROPOS-RSD/earthcarekit)
-- [License (MIT)](https://github.com/TROPOS-RSD/earthcarekit/blob/main/LICENSE)
-- [Citation (Zenodo)](link)
+- [License (Apache-2.0)](https://github.com/TROPOS-RSD/earthcarekit/blob/main/LICENSE)
+- [Citation (Zenodo)](http://doi.org/10.5281/zenodo.16813294)
 
 ---
 
@@ -18,9 +18,9 @@ Copyright (c) 2025 Leonard König
 """
 
 __author__ = "Leonard König"
-__license__ = "MIT"
-__version__ = "0.7.1"
-__date__ = "2025-09-26"
+__license__ = "Apache-2.0"
+__version__ = "0.11.0"
+__date__ = "2025-11-14"
 __maintainer__ = "Leonard König"
 __email__ = "koenig@tropos.de"
 __title__ = "earthcarekit"
@@ -30,14 +30,18 @@ import sys
 from .calval import *
 from .download import ecdownload
 from .plot import *
-from .plot import ecquicklook, ecswath
+from .plot import FigureType, ecquicklook, ecswath
 from .utils import ProfileData, filter_latitude, filter_radius, filter_time, geo, read
 from .utils import statistics as stats
 from .utils.config import (
     _warn_user_if_not_default_config_exists,
     create_example_config,
+    get_config,
     get_default_config_filepath,
     set_config,
+    set_config_maap_token,
+    set_config_to_maap,
+    set_config_to_oads,
 )
 from .utils.geo import geodesic, get_coord_between, get_coords, haversine
 from .utils.ground_sites import GroundSite, get_ground_site
@@ -56,6 +60,7 @@ __all__ = [
     "ecswath",
     "ecdownload",
     "ProfileData",
+    "filter_latitude",
     "filter_radius",
     "filter_time",
     "GroundSite",
@@ -65,9 +70,14 @@ __all__ = [
     "haversine",
     "get_coords",
     "get_coord_between",
+    "get_config",
     "set_config",
+    "set_config_maap_token",
+    "set_config_to_maap",
+    "set_config_to_oads",
     "create_example_config",
     "get_default_config_filepath",
+    "FigureType",
 ]
 
 _setup_logging()
