@@ -12,6 +12,7 @@ import requests.cookies
 
 from ..utils import get_product_info
 from ..utils._cli import console_exclusive_info, get_counter_message
+from ..utils.config import ECKConfig
 from ._auth_oads import get_oads_authentification_cookies
 from ._eo_collection import EOCollection
 from ._eo_parameters import STACQueryParameter, get_available_parameters
@@ -36,26 +37,51 @@ def ensure_single_zip_extension(filename):
     return base_name + ".ZIP"
 
 
-def get_product_sub_dirname(product_name: str) -> str:
+def get_product_sub_dirname(
+    product_name: str,
+    config: ECKConfig | None = None,
+) -> str:
     """Returns level subfolder name of given product name."""
+    if isinstance(config, ECKConfig):
+        subdir_name_aux_files = config.subdir_name_auxiliary_files
+        subdir_name_orb_files = config.subdir_name_orbit_files
+        subdir_name_l0__files = config.subdir_name_level0
+        subdir_name_l1b_files = config.subdir_name_level1b
+        subdir_name_l1c_files = config.subdir_name_level1c
+        subdir_name_l2a_files = config.subdir_name_level2a
+        subdir_name_l2b_files = config.subdir_name_level2b
+    else:
+        subdir_name_aux_files = SUBDIR_NAME_AUX_FILES
+        subdir_name_orb_files = SUBDIR_NAME_ORB_FILES
+        subdir_name_l0__files = SUBDIR_NAME_L0__FILES
+        subdir_name_l1b_files = SUBDIR_NAME_L1B_FILES
+        subdir_name_l1c_files = SUBDIR_NAME_L1C_FILES
+        subdir_name_l2a_files = SUBDIR_NAME_L2A_FILES
+        subdir_name_l2b_files = SUBDIR_NAME_L2B_FILES
+
     if product_name in ["AUX_JSG_1D", "AUX_MET_1D"]:
-        sub_dirname = SUBDIR_NAME_AUX_FILES
+        sub_dirname = subdir_name_aux_files
     elif product_name in ["MPL_ORBSCT", "AUX_ORBPRE", "AUX_ORBRES"]:
-        sub_dirname = SUBDIR_NAME_ORB_FILES
+        sub_dirname = subdir_name_orb_files
     elif "0" in product_name.lower():
-        sub_dirname = SUBDIR_NAME_L0__FILES
+        sub_dirname = subdir_name_l0__files
     elif "1b" in product_name.lower():
-        sub_dirname = SUBDIR_NAME_L1B_FILES
+        sub_dirname = subdir_name_l1b_files
     elif "1c" in product_name.lower():
-        sub_dirname = SUBDIR_NAME_L1C_FILES
+        sub_dirname = subdir_name_l1c_files
     elif "2a" in product_name.lower():
-        sub_dirname = SUBDIR_NAME_L2A_FILES
+        sub_dirname = subdir_name_l2a_files
     elif "2b" in product_name.lower():
-        sub_dirname = SUBDIR_NAME_L2B_FILES
+        sub_dirname = subdir_name_l2b_files
     return sub_dirname
 
 
-def get_local_product_dirpath(dirpath_local, filename, create_subdirs=True):
+def get_local_product_dirpath(
+    dirpath_local: str,
+    filename: str,
+    create_subdirs: bool = True,
+    config: ECKConfig | None = None,
+):
     """Creates local path to file."""
     if create_subdirs:
         product_info = get_product_info(filename, must_exist=False)
@@ -66,10 +92,27 @@ def get_local_product_dirpath(dirpath_local, filename, create_subdirs=True):
         day = str(product_info.start_sensing_time.day).zfill(2)
         baseline = str(product_info.baseline).upper()
 
-        sub_dirname = get_product_sub_dirname(product_name)
-        product_dirpath_local = os.path.join(
-            dirpath_local, sub_dirname, product_name, year, month, day, baseline
-        )
+        sub_dirname = get_product_sub_dirname(product_name, config=config)
+
+        if isinstance(config, ECKConfig):
+            template = config.subdir_template
+            subdir_path = template.format(
+                **{
+                    "level": sub_dirname,
+                    "file_type": product_name,
+                    "year": year,
+                    "month": month,
+                    "day": day,
+                    "baseline": baseline,
+                }
+            )
+            product_dirpath_local = os.path.abspath(
+                os.path.join(dirpath_local, subdir_path)
+            )
+        else:
+            product_dirpath_local = os.path.join(
+                dirpath_local, sub_dirname, product_name, year, month, day, baseline
+            )
     else:
         product_dirpath_local = dirpath_local
     return product_dirpath_local
@@ -122,7 +165,8 @@ class EOProduct:
         counter: int | None = None,
         total_count: int | None = None,
         attempts: int = 3,
-        chunk_size_bytes: int = 256 * 1024,
+        chunk_size_bytes: int = 1 * 1024 * 1024,
+        config: ECKConfig | None = None,
         logger: Logger | None = None,
     ) -> _DownloadResult:
         headers_maap: dict[str, str] | None = None
@@ -160,7 +204,10 @@ class EOProduct:
         product_info = get_product_info(self.url_download, must_exist=False)
         file_name: str = product_info.name
         product_dirpath = get_local_product_dirpath(
-            download_directory, file_name, create_subdirs=is_create_subdirs
+            download_directory,
+            file_name,
+            create_subdirs=is_create_subdirs,
+            config=config,
         )
 
         # Make sure the local download_directory exists (if not create it)
@@ -241,6 +288,17 @@ class EOProduct:
                         )
                     validate_request_response(file_download_response, logger=logger)
 
+                    if file_download_url.split(".")[-1] == "h5":
+                        if is_create_subdirs:
+                            zip_file_path = os.path.join(
+                                zip_file_path[0:-4],
+                                f"{os.path.basename(zip_file_path)[0:-4]}.h5",
+                            )
+                        else:
+                            zip_file_path = f"{zip_file_path[0:-4]}.h5"
+                        if not os.path.exists(os.path.dirname(zip_file_path)):
+                            os.makedirs(os.path.dirname(zip_file_path))
+
                     with open(zip_file_path, "wb") as f:
                         total_length_str = file_download_response.headers.get(
                             "content-length"
@@ -260,7 +318,7 @@ class EOProduct:
                         current_length = 0
                         total_length = self.size
                         start_time = time.time()
-                        progress_bar_length = 30
+                        progress_bar_length: int = 30
                         for data in file_download_response.iter_content(
                             chunk_size=chunk_size_bytes,
                         ):
@@ -330,7 +388,7 @@ class EOProduct:
                 _success &= download_success
 
             # Unzip zip file
-            if try_unzip:
+            if try_unzip and file_download_url.split(".")[-1] != "h5":
                 _success = unzip_file(
                     zip_file_path,
                     delete=is_delete,
@@ -391,6 +449,7 @@ def get_available_products(
     collection: EOCollection,
     params: dict[str, str],
     logger: Logger | None = None,
+    download_only_h5: bool = False,
 ) -> list[EOProduct]:
     """Returns products matching user inputs from the specified collection."""
     url_search = _create_search_url(
@@ -460,7 +519,10 @@ def get_available_products(
             _rel = link.get("rel")
             _type = link.get("type")
 
-            if _rel in ["enclosure", "archives"] and _type == "application/zip":
+            _application = "application/zip"
+            if download_only_h5:
+                _application = "application/x-hdf5"
+            if _rel in ["enclosure", "archives"] and _type == _application:
                 url_download = link.get("href", None)
                 if not isinstance(url_download, str):
                     server = str(urlp.urlparse(url_download).netloc)
