@@ -3,14 +3,21 @@ import seaborn as sns
 from .color import Cmap, Color, ColorLike, cmaps, get_cmap, shift_cmap
 from .figure import (
     CurtainFigure,
+    FigureType,
     LineFigure,
     MapFigure,
     ProfileFigure,
     SwathFigure,
-    create_column_subfigures,
-    create_fig_layout_map_main_zoom_profile,
+    create_column_figure_layout,
+    create_multi_figure_layout,
+    plot_line_between_figures,
+)
+from .quicklook import (
+    ecquicklook,
+    ecquicklook_deep_convection,
+    ecquicklook_psc,
+    ecswath,
 )
-from .quicklook import ecquicklook, ecswath
 from .save import save_plot
 
 sns.set_style("ticks")
@@ -28,9 +35,12 @@ __all__ = [
     "MapFigure",
     "ProfileFigure",
     "SwathFigure",
-    "create_column_subfigures",
-    "create_fig_layout_map_main_zoom_profile",
+    "create_column_figure_layout",
+    "create_multi_figure_layout",
     "ecquicklook",
     "ecswath",
+    "ecquicklook_deep_convection",
+    "ecquicklook_psc",
     "save_plot",
+    "plot_line_between_figures",
 ]
