@@ -1,10 +1,8 @@
+from ._plot_line_between_figures import plot_line_between_figures
 from .curtain import CurtainFigure
 from .figure_type import ECKFigure, FigureType
 from .line import LineFigure
 from .map import MapFigure
-from .multi_panel import (
-    create_column_subfigures,
-    create_fig_layout_map_main_zoom_profile,
-)
+from .multi_panel import create_column_figure_layout, create_multi_figure_layout
 from .profile import ProfileFigure
 from .swath import SwathFigure
