@@ -1,6 +1,7 @@
 import warnings
 from typing import Iterable, Literal, Sequence
 
+import matplotlib.patheffects as pe
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
@@ -18,10 +19,12 @@ from numpy.typing import ArrayLike, NDArray
 
 from ...utils.constants import (
     ALONG_TRACK_DIM,
+    DEFAULT_COLORBAR_WIDTH,
     ELEVATION_VAR,
     FIGURE_HEIGHT_CURTAIN,
     FIGURE_WIDTH_CURTAIN,
     HEIGHT_VAR,
+    LAND_FLAG_VAR,
     PRESSURE_VAR,
     TEMP_CELSIUS_VAR,
     TIME_VAR,
@@ -49,7 +52,7 @@ from ...utils.time import (
 from ...utils.typing import DistanceRangeLike, ValueRangeLike, validate_numeric_range
 from ..color import Cmap, Color, ColorLike, get_cmap
 from ..save import save_plot
-from ..text import shade_around_text
+from ..text import add_shade_to_text
 from .along_track import AlongTrackAxisStyle, format_along_track_axis
 from .annotation import (
     add_text,
@@ -57,7 +60,7 @@ from .annotation import (
     add_title_earthcare_frame,
     format_var_label,
 )
-from .colorbar import add_vertical_colorbar
+from .colorbar import add_colorbar
 from .defaults import get_default_cmap, get_default_norm, get_default_rolling_mean
 from .height_ticks import format_height_ticks
 
@@ -151,19 +154,11 @@ class CurtainFigure:
         title (str | None, optional): Title to display above the curtain plot. Defaults to None.
         ax_style_top (AlongTrackAxisStyle | str, optional): Style of the top x-axis, e.g., "geo", "time", or "frame". Defaults to "geo".
         ax_style_bottom (AlongTrackAxisStyle | str, optional): Style of the bottom x-axis, e.g., "geo", "time", or "frame". Defaults to "time".
-        num_ticks (int, optional): Number of tick marks to place along the x-axis. Defaults to 10.
+        num_ticks (int, optional): Maximum number of tick marks to be place along the x-axis. Defaults to 10.
         show_height_left (bool, optional): Whether to show height labels on the left y-axis. Defaults to True.
         show_height_right (bool, optional): Whether to show height labels on the right y-axis. Defaults to False.
         mode (Literal["exact", "fast"], optional): Curtain plotting mode. Use "fast" to speed up plotting by coarsening data to at least `min_num_profiles`; "exact" plots full resolution. Defaults to None.
         min_num_profiles (int, optional): Minimum number of profiles to keep when using "fast" mode. Defaults to 1000.
-
-    Example:
-        ```python
-        import earthcarekit as eck
-
-        fig = eck.CurtainFigure(ax_style_top="geo", ax_style_bottom="frame")
-        fig = fig.ecplot(ds, variable="beta_att_1064")
-        ```
     """
 
     def __init__(
@@ -180,8 +175,11 @@ class CurtainFigure:
         mode: Literal["exact", "fast"] = "fast",
         min_num_profiles: int = 1000,
         colorbar_tick_scale: float | None = None,
+        fig_height_scale: float = 1.0,
+        fig_width_scale: float = 1.0,
     ):
         self.fig: Figure
+        figsize = (figsize[0] * fig_width_scale, figsize[1] * fig_height_scale)
         if isinstance(ax, Axes):
             tmp = ax.get_figure()
             if not isinstance(tmp, (Figure, SubFigure)):
@@ -327,6 +325,14 @@ class CurtainFigure:
         colorbar: bool = True,
         colorbar_ticks: ArrayLike | None = None,
         colorbar_tick_labels: ArrayLike | None = None,
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "right",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.2,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         rolling_mean: int | None = None,
         selection_time_range: TimeRangeLike | None = None,
         selection_color: str | None = Color("ec:earthcare"),
@@ -404,7 +410,7 @@ class CurtainFigure:
         if isinstance(min_num_profiles, int):
             self.min_num_profiles = min_num_profiles
 
-        if isinstance(value_range, Iterable):
+        if isinstance(value_range, Sequence):
             if len(value_range) != 2:
                 raise ValueError(
                     f"invalid `value_range`: {value_range}, expecting (vmin, vmax)"
@@ -535,13 +541,16 @@ class CurtainFigure:
                 for i in [0, -1]:
                     height_range = list(height_range)
                     if height_range[i] is None:
-                        height_range[i] = np.atleast_2d(vp.height)[0, i]
+                        height_range[i] = [
+                            np.nanmin(vp.height),
+                            np.nanmax(vp.height),
+                        ][i]
                     height_range = tuple(height_range)
             vp = vp.select_height_range(height_range, pad_idx=1)
         else:
             height_range = (
-                np.atleast_2d(vp.height)[0, 0],
-                np.atleast_2d(vp.height)[0, -1],
+                np.nanmin(vp.height),
+                np.nanmax(vp.height),
             )
 
         if time_range is not None:
@@ -589,27 +598,39 @@ class CurtainFigure:
             norm=norm,
             shading="auto",
             linewidth=0,
+            rasterized=True,
             **kwargs,
         )
         mesh.set_edgecolor("face")
 
         if colorbar:
+            cb_kwargs = dict(
+                label=format_var_label(vp.label, vp.units, label_len=label_length),
+                position=colorbar_position,
+                alignment=colorbar_alignment,
+                width=colorbar_width,
+                spacing=colorbar_spacing,
+                length_ratio=colorbar_length_ratio,
+                label_outside=colorbar_label_outside,
+                ticks_outside=colorbar_ticks_outside,
+                ticks_both=colorbar_ticks_both,
+            )
             if cmap.categorical:
-                self.colorbar = add_vertical_colorbar(
+                self.colorbar = add_colorbar(
                     fig=self.fig,
                     ax=self.ax,
                     data=mesh,
-                    label=format_var_label(vp.label, vp.units, label_len=label_length),
                     cmap=cmap,
+                    **cb_kwargs,  # type: ignore
                 )
             else:
-                self.colorbar = add_vertical_colorbar(
+                self.colorbar = add_colorbar(
                     fig=self.fig,
                     ax=self.ax,
                     data=mesh,
-                    label=format_var_label(vp.label, vp.units, label_len=label_length),
                     ticks=colorbar_ticks,
                     tick_labels=colorbar_tick_labels,
+                    **cb_kwargs,  # type: ignore
                 )
 
         if selection_time_range is not None:
@@ -719,7 +740,7 @@ class CurtainFigure:
         show_radius: bool = True,
         info_text_loc: str | None = None,
         # Common args for wrappers
-        value_range: ValueRangeLike | None = None,
+        value_range: ValueRangeLike | Literal["default"] | None = "default",
         log_scale: bool | None = None,
         norm: Normalize | None = None,
         time_range: TimeRangeLike | None = None,
@@ -730,6 +751,14 @@ class CurtainFigure:
         colorbar: bool = True,
         colorbar_ticks: ArrayLike | None = None,
         colorbar_tick_labels: ArrayLike | None = None,
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "right",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.2,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         rolling_mean: int | None = None,
         selection_time_range: TimeRangeLike | None = None,
         selection_color: str | None = Color("ec:earthcare"),
@@ -875,14 +904,18 @@ class CurtainFigure:
             )
         if units is None:
             all_args["units"] = "-" if not hasattr(ds[var], "units") else ds[var].units
-        if value_range is None and log_scale is None and norm is None:
-            all_args["norm"] = get_default_norm(var)
+        if isinstance(value_range, str) and value_range == "default":
+            value_range = None
+            all_args["value_range"] = None
+            if log_scale is None and norm is None:
+                all_args["norm"] = get_default_norm(var, file_type=ds)
         if rolling_mean is None:
-            all_args["rolling_mean"] = get_default_rolling_mean(var)
+            all_args["rolling_mean"] = get_default_rolling_mean(var, file_type=ds)
         if cmap is None:
             all_args["cmap"] = get_default_cmap(var, file_type=ds)
+        all_args["cmap"] = get_cmap(all_args["cmap"])
 
-        if all_args["cmap"] == "synergistic_tc":
+        if all_args["cmap"] == get_cmap("synergetic_tc"):
             self.colorbar_tick_scale = 0.8
 
         # Handle overpass
@@ -936,6 +969,7 @@ class CurtainFigure:
                     list(_mark_profiles_at_linewidth).append(2.5)
                     all_args["mark_profiles_at_linewidth"] = _mark_profiles_at_linewidth
 
+                all_args["selection_linestyle"] = "none"
                 all_args["selection_linewidth"] = 0.1
         self.plot(**all_args)
 
@@ -974,6 +1008,7 @@ class CurtainFigure:
             _fb1 = self.ax.fill_between(
                 tnew,
                 hnew,
+                y2=-5e3,
                 color=color,
                 alpha=alpha,
                 zorder=zorder,
@@ -1075,6 +1110,32 @@ class CurtainFigure:
         if len(y.shape) == 2:
             y = y[len(y) // 2]
 
+        if isinstance(colors, list):
+            shade_color = Color.from_optional(colors[0])
+        else:
+            shade_color = Color.from_optional(colors)
+
+        if isinstance(shade_color, Color):
+            shade_color = shade_color.get_best_bw_contrast_color()
+
+        linewidths2: int | float | np.ndarray
+        if not isinstance(linewidths, (int, float, np.number, np.ndarray)):
+            linewidths2 = np.array(linewidths) * 2.5
+        else:
+            linewidths2 = linewidths * 2.5
+
+        cn2 = self.ax.contour(
+            x,
+            y,
+            z,
+            levels=levels,
+            linewidths=linewidths2,
+            colors=shade_color,
+            alpha=0.5,
+            linestyles="solid",
+            zorder=zorder,
+        )
+
         cn = self.ax.contour(
             x,
             y,
@@ -1101,12 +1162,9 @@ class CurtainFigure:
             zorder=zorder,
         )
 
-        bold_font = font_manager.FontProperties(weight="bold")
-        for text in cl:
-            text.set_fontproperties(bold_font)
-
-        for l in cn.labelTexts:
-            l.set_rotation(0)
+        for t in cn.labelTexts:
+            add_shade_to_text(t, alpha=0.5)
+            t.set_rotation(0)
 
         return self
 
@@ -1230,6 +1288,7 @@ class CurtainFigure:
         height_var: str = HEIGHT_VAR,
         levels: list | NDArray | None = None,
         label_format: str | None = None,
+        label_levels: list | NDArray | None = None,
         linewidths: int | float | list | NDArray | None = 1.5,
         linestyles: str | list | NDArray | None = "solid",
         colors: Color | str | list | NDArray | None = "black",
@@ -1239,16 +1298,18 @@ class CurtainFigure:
         values = ds[var].values
         time = ds[time_var].values
         height = ds[height_var].values
+        tp = ProfileData(values=values, time=time, height=height)
         self.plot_contour(
-            values=values,
-            time=time,
-            height=height,
+            values=tp.values,
+            time=tp.time,
+            height=tp.height,
             levels=levels,
             linewidths=linewidths,
             linestyles=linestyles,
             colors=colors,
             zorder=zorder,
             label_format=label_format,
+            label_levels=label_levels,
         )
         return self
 
@@ -1256,7 +1317,48 @@ class CurtainFigure:
         self,
         ds: xr.Dataset,
         var: str = TEMP_CELSIUS_VAR,
-        label_format: str | None = r"$%.0f^{\circ}$C",
+        label_format: str | None = "$%.0f^{\circ}$C",
+        label_levels: list | NDArray | None = [-80, -40, 0],
+        levels=[
+            -80,
+            -70,
+            -60,
+            -50,
+            -40,
+            -30,
+            -20,
+            -10,
+            0,
+            10,
+            20,
+        ],
+        linewidths=[
+            0.75,  # -80
+            0.25,  # -70
+            0.50,  # -60
+            0.50,  # -50
+            0.75,  # -40
+            0.50,  # -30
+            0.75,  # -20
+            0.50,  # -10
+            1.00,  # 0
+            0.50,  # 10
+            0.75,  # 20
+        ],
+        linestyles=[
+            "dashed",  # -80
+            "dashed",  # -70
+            "dashed",  # -60
+            "dashed",  # -50
+            "dashed",  # -40
+            "dashed",  # -30
+            "dashed",  # -20
+            "dashed",  # -10
+            "solid",  # 0
+            "solid",  # 10
+            "solid",  # 20
+        ],
+        colors="black",
         **kwargs,
     ) -> "CurtainFigure":
         """Adds temperature contour lines to the plot."""
@@ -1264,6 +1366,11 @@ class CurtainFigure:
             ds=ds,
             var=var,
             label_format=label_format,
+            levels=levels,
+            label_levels=label_levels,
+            linewidths=linewidths,
+            linestyles=linestyles,
+            colors=colors,
             **kwargs,
         )
 
@@ -1293,24 +1400,50 @@ class CurtainFigure:
         ds: xr.Dataset,
         var: str = ELEVATION_VAR,
         time_var: str = TIME_VAR,
-        color: Color | str | None = "ec:elevation",
+        land_flag_var: str = LAND_FLAG_VAR,
+        color: Color | str | None = "ec:land",
+        color_water: Color | str | None = "ec:water",
         legend_label: str | None = None,
+        legend_label_water: str | None = None,
     ) -> "CurtainFigure":
         """Adds filled elevation/surface area to the plot."""
-        height = ds[var].values
-        time = ds[time_var].values
-        self.plot_height(
-            height=height,
-            time=time,
+        height = ds[var].copy().values
+        time = ds[time_var].copy().values
+
+        kwargs = dict(
             linewidth=0,
             linestyle="none",
-            color=color,
             marker="none",
             markersize=0,
             fill=True,
             zorder=10,
-            legend_label=legend_label,
         )
+
+        is_water = land_flag_var in ds.variables
+
+        if is_water:
+            land_flag = ds[land_flag_var].copy().values == 1
+            height_water = height.copy()
+            height_water[land_flag] = np.nan
+            height[~land_flag] = np.nan
+
+        self.plot_height(
+            height=height,
+            time=time,
+            color=color,
+            legend_label=legend_label,
+            **kwargs,  # type: ignore
+        )
+
+        if is_water:
+            self.plot_height(
+                height=height_water,
+                time=time,
+                color=color_water,
+                legend_label=legend_label_water,
+                **kwargs,  # type: ignore
+            )
+
         return self
 
     def ecplot_tropopause(
@@ -1438,7 +1571,7 @@ class CurtainFigure:
                 text.set_fontweight(textweight)
 
                 if textshadealpha > 0:
-                    text = shade_around_text(
+                    text = add_shade_to_text(
                         text,
                         alpha=textshadealpha,
                         linewidth=textshadewidth,
@@ -1477,9 +1610,83 @@ class CurtainFigure:
             cb.ax.tick_params(labelsize=_fontsize * multiplier)
         return self
 
-    def show(self):
-        self.fig.tight_layout()
-        self.fig.show()
+    def show(self) -> None:
+        import IPython
+        import matplotlib.pyplot as plt
+        from IPython.display import display
 
-    def save(self, filename: str = "", filepath: str | None = None, **kwargs):
-        save_plot(fig=self.fig, filename=filename, filepath=filepath, **kwargs)
+        if IPython.get_ipython() is not None:
+            display(self.fig)
+        else:
+            plt.show()
+
+    def save(
+        self,
+        filename: str = "",
+        filepath: str | None = None,
+        ds: xr.Dataset | None = None,
+        ds_filepath: str | None = None,
+        dpi: float | Literal["figure"] = "figure",
+        orbit_and_frame: str | None = None,
+        utc_timestamp: TimestampLike | None = None,
+        use_utc_creation_timestamp: bool = False,
+        site_name: str | None = None,
+        hmax: int | float | None = None,
+        radius: int | float | None = None,
+        extra: str | None = None,
+        transparent_outside: bool = False,
+        verbose: bool = True,
+        print_prefix: str = "",
+        create_dirs: bool = False,
+        transparent_background: bool = False,
+        resolution: str | None = None,
+        **kwargs,
+    ) -> None:
+        """
+        Save a figure as an image or vector graphic to a file and optionally format the file name in a structured way using EarthCARE metadata.
+
+        Args:
+            figure (Figure | HasFigure): A figure object (`matplotlib.figure.Figure`) or objects exposing a `.fig` attribute containing a figure (e.g., `CurtainFigure`).
+            filename (str, optional): The base name of the file. Can be extended based on other metadata provided. Defaults to empty string.
+            filepath (str | None, optional): The path where the image is saved. Can be extended based on other metadata provided. Defaults to None.
+            ds (xr.Dataset | None, optional): A EarthCARE dataset from which metadata will be taken. Defaults to None.
+            ds_filepath (str | None, optional): A path to a EarthCARE product from which metadata will be taken. Defaults to None.
+            pad (float, optional): Extra padding (i.e., empty space) around the image in inches. Defaults to 0.1.
+            dpi (float | 'figure', optional): The resolution in dots per inch. If 'figure', use the figure's dpi value. Defaults to None.
+            orbit_and_frame (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            utc_timestamp (TimestampLike | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            use_utc_creation_timestamp (bool, optional): Whether the time of image creation should be included in the file name. Defaults to False.
+            site_name (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            hmax (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            radius (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            resolution (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            extra (str | None, optional): A custom string to be included in the file name. Defaults to None.
+            transparent_outside (bool, optional): Whether the area outside figures should be transparent. Defaults to False.
+            verbose (bool, optional): Whether the progress of image creation should be printed to the console. Defaults to True.
+            print_prefix (str, optional): A prefix string to all console messages. Defaults to "".
+            create_dirs (bool, optional): Whether images should be saved in a folder structure based on provided metadata. Defaults to False.
+            transparent_background (bool, optional): Whether the background inside and outside of figures should be transparent. Defaults to False.
+            **kwargs (dict[str, Any]): Keyword arguments passed to wrapped function call of `matplotlib.pyplot.savefig`.
+        """
+        save_plot(
+            fig=self.fig,
+            filename=filename,
+            filepath=filepath,
+            ds=ds,
+            ds_filepath=ds_filepath,
+            dpi=dpi,
+            orbit_and_frame=orbit_and_frame,
+            utc_timestamp=utc_timestamp,
+            use_utc_creation_timestamp=use_utc_creation_timestamp,
+            site_name=site_name,
+            hmax=hmax,
+            radius=radius,
+            extra=extra,
+            transparent_outside=transparent_outside,
+            verbose=verbose,
+            print_prefix=print_prefix,
+            create_dirs=create_dirs,
+            transparent_background=transparent_background,
+            resolution=resolution,
+            **kwargs,
+        )
