@@ -2,11 +2,14 @@ from enum import IntEnum
 from typing import TypeAlias
 
 from .curtain import CurtainFigure
+from .line import LineFigure
 from .map import MapFigure
 from .profile import ProfileFigure
 from .swath import SwathFigure
 
-ECKFigure: TypeAlias = MapFigure | CurtainFigure | SwathFigure | ProfileFigure
+ECKFigure: TypeAlias = (
+    MapFigure | CurtainFigure | SwathFigure | ProfileFigure | LineFigure
+)
 
 
 class FigureType(IntEnum):
@@ -20,3 +23,8 @@ class FigureType(IntEnum):
     PROFILE = 6
     LINE = 7
     LINE_ZOOMED = 8
+    CURTAIN_75 = 9
+    CURTAIN_67 = 10
+    CURTAIN_50 = 11
+    CURTAIN_33 = 12
+    CURTAIN_25 = 13
