@@ -60,7 +60,7 @@ from .annotation import (
     add_title_earthcare_frame,
     format_var_label,
 )
-from .colorbar import add_vertical_colorbar
+from .colorbar import add_colorbar
 from .defaults import get_default_cmap, get_default_norm, get_default_rolling_mean
 from .height_ticks import format_height_ticks
 from .ticks import format_numeric_ticks
@@ -88,7 +88,10 @@ class LineFigure:
         grid_axis: Literal["both", "x", "y"] = "both",
         grid_linestyle: str = "dashed",
         grid_linewidth: float = 1,
+        fig_height_scale: float = 1.0,
+        fig_width_scale: float = 1.0,
     ):
+        figsize = (figsize[0] * fig_width_scale, figsize[1] * fig_height_scale)
         self.fig: Figure
         if isinstance(ax, Axes):
             tmp = ax.get_figure()
@@ -134,6 +137,9 @@ class LineFigure:
         self.ax_top = self.ax.twiny()
         self.ax_top.set_xlim(self.ax.get_xlim())
 
+        self.tmin: np.datetime64 | None = None
+        self.tmax: np.datetime64 | None = None
+
     def _set_info_text_loc(self, info_text_loc: str | None) -> None:
         if isinstance(info_text_loc, str):
             self.info_text_loc = info_text_loc
@@ -244,7 +250,7 @@ class LineFigure:
         prob_labels: list[str] | None = None,
         prob_colors: list[ColorLike] | None = None,
         zorder: int | float | None = None,
-        label_length: int = 25,
+        label_length: int = 20,
         **kwargs,
     ) -> "LineFigure":
         _zorder: float = 2.0
@@ -305,8 +311,8 @@ class LineFigure:
                 f"Since {is_prob=} values must be 1D, but has shape={values.shape}"
             )
 
-        tmin_original = time[0]
-        tmax_original = time[-1]
+        tmin_original = np.datetime64(to_timestamp(time[0]))
+        tmax_original = np.datetime64(to_timestamp(time[-1]))
         vmin_original = values[0]
         vmax_original = values[-1]
 
@@ -353,8 +359,18 @@ class LineFigure:
                     if time_range[i] is None:
                         time_range[i] = time[i]
                     time_range = tuple(time_range)  # type: ignore
+            time_range = (
+                np.datetime64(to_timestamp(time_range[0])),
+                np.datetime64(to_timestamp(time_range[-1])),
+            )
+            self.tmin = time_range[0]
+            self.tmax = time_range[1]
         else:
             time_range = (time[0], time[-1])
+        time_range = (
+            np.datetime64(to_timestamp(time_range[0])),
+            np.datetime64(to_timestamp(time_range[-1])),
+        )
 
         _value_range: tuple[float, float] = select_value_range(
             data=values,
@@ -363,8 +379,8 @@ class LineFigure:
             use_min_max=True,
         )
 
-        tmin = np.datetime64(time_range[0])
-        tmax = np.datetime64(time_range[1])
+        tmin = self.tmin or np.datetime64(time_range[0])
+        tmax = self.tmax or np.datetime64(time_range[1])
 
         vmin: float = _value_range[0]
         vmax: float = _value_range[1]
@@ -438,6 +454,7 @@ class LineFigure:
                 ax=self.ax,
                 axis="y",
                 label=format_var_label(label, units, label_len=label_length),
+                max_line_length=label_length,
                 show_label=self.show_value_left,
                 show_values=self.show_value_left,
             )
@@ -445,6 +462,7 @@ class LineFigure:
                 ax=self.ax_right,
                 axis="y",
                 label=format_var_label(label, units, label_len=label_length),
+                max_line_length=label_length,
                 show_label=self.show_value_right,
                 show_values=self.show_value_right,
             )
@@ -457,12 +475,14 @@ class LineFigure:
                         self.selection_time_range[0],  # type: ignore
                         color=selection_highlight_color,
                         alpha=selection_highlight_alpha,
+                        zorder=3,
                     )
                     self.ax.axvspan(
                         self.selection_time_range[1],  # type: ignore
                         tmax,  # type: ignore
                         color=selection_highlight_color,
                         alpha=selection_highlight_alpha,
+                        zorder=3,
                     )
                 else:
                     self.ax.axvspan(
@@ -470,6 +490,7 @@ class LineFigure:
                         self.selection_time_range[1],  # type: ignore
                         color=selection_highlight_color,
                         alpha=selection_highlight_alpha,
+                        zorder=3,
                     )
 
             for t in self.selection_time_range:  # type: ignore
@@ -478,6 +499,7 @@ class LineFigure:
                     color=selection_color,
                     linestyle=selection_linestyle,
                     linewidth=selection_linewidth,
+                    zorder=3,
                 )
 
         self._set_axes(
@@ -496,7 +518,13 @@ class LineFigure:
 
         if mark_profiles_at is not None:
             for t in to_timestamps(mark_profiles_at):
-                self.ax.axvline(t, color=selection_color, linestyle="solid", linewidth=selection_linewidth)  # type: ignore
+                self.ax.axvline(
+                    t,  # type: ignore
+                    color=selection_color,
+                    linestyle="solid",
+                    linewidth=selection_linewidth,
+                    zorder=3,
+                )
 
         return self
 
@@ -552,7 +580,7 @@ class LineFigure:
         prob_labels: list[str] | None = None,
         prob_colors: list[ColorLike] | None = None,
         zorder: int | float | None = None,
-        label_length: int = 25,
+        label_length: int = 20,
         **kwargs,
     ) -> "LineFigure":
         # Collect all common args for wrapped plot function call
@@ -593,7 +621,7 @@ class LineFigure:
         if classes is not None and len(classes) > 0:
             all_args["value_range"] = (-0.5, len(classes) - 0.5)
         elif value_range is None and log_scale is None and norm is None:
-            all_args["norm"] = get_default_norm(var)
+            all_args["norm"] = get_default_norm(var, file_type=ds)
 
         # Handle overpass
         _site: GroundSite | None = None
@@ -668,9 +696,83 @@ class LineFigure:
             self.ax_right.invert_yaxis()
         return self
 
-    def show(self):
-        self.fig.tight_layout()
-        self.fig.show()
+    def show(self) -> None:
+        import IPython
+        import matplotlib.pyplot as plt
+        from IPython.display import display
 
-    def save(self, filename: str = "", filepath: str | None = None, **kwargs):
-        save_plot(fig=self.fig, filename=filename, filepath=filepath, **kwargs)
+        if IPython.get_ipython() is not None:
+            display(self.fig)
+        else:
+            plt.show()
+
+    def save(
+        self,
+        filename: str = "",
+        filepath: str | None = None,
+        ds: xr.Dataset | None = None,
+        ds_filepath: str | None = None,
+        dpi: float | Literal["figure"] = "figure",
+        orbit_and_frame: str | None = None,
+        utc_timestamp: TimestampLike | None = None,
+        use_utc_creation_timestamp: bool = False,
+        site_name: str | None = None,
+        hmax: int | float | None = None,
+        radius: int | float | None = None,
+        extra: str | None = None,
+        transparent_outside: bool = False,
+        verbose: bool = True,
+        print_prefix: str = "",
+        create_dirs: bool = False,
+        transparent_background: bool = False,
+        resolution: str | None = None,
+        **kwargs,
+    ) -> None:
+        """
+        Save a figure as an image or vector graphic to a file and optionally format the file name in a structured way using EarthCARE metadata.
+
+        Args:
+            figure (Figure | HasFigure): A figure object (`matplotlib.figure.Figure`) or objects exposing a `.fig` attribute containing a figure (e.g., `CurtainFigure`).
+            filename (str, optional): The base name of the file. Can be extended based on other metadata provided. Defaults to empty string.
+            filepath (str | None, optional): The path where the image is saved. Can be extended based on other metadata provided. Defaults to None.
+            ds (xr.Dataset | None, optional): A EarthCARE dataset from which metadata will be taken. Defaults to None.
+            ds_filepath (str | None, optional): A path to a EarthCARE product from which metadata will be taken. Defaults to None.
+            pad (float, optional): Extra padding (i.e., empty space) around the image in inches. Defaults to 0.1.
+            dpi (float | 'figure', optional): The resolution in dots per inch. If 'figure', use the figure's dpi value. Defaults to None.
+            orbit_and_frame (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            utc_timestamp (TimestampLike | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            use_utc_creation_timestamp (bool, optional): Whether the time of image creation should be included in the file name. Defaults to False.
+            site_name (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            hmax (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            radius (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            resolution (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            extra (str | None, optional): A custom string to be included in the file name. Defaults to None.
+            transparent_outside (bool, optional): Whether the area outside figures should be transparent. Defaults to False.
+            verbose (bool, optional): Whether the progress of image creation should be printed to the console. Defaults to True.
+            print_prefix (str, optional): A prefix string to all console messages. Defaults to "".
+            create_dirs (bool, optional): Whether images should be saved in a folder structure based on provided metadata. Defaults to False.
+            transparent_background (bool, optional): Whether the background inside and outside of figures should be transparent. Defaults to False.
+            **kwargs (dict[str, Any]): Keyword arguments passed to wrapped function call of `matplotlib.pyplot.savefig`.
+        """
+        save_plot(
+            fig=self.fig,
+            filename=filename,
+            filepath=filepath,
+            ds=ds,
+            ds_filepath=ds_filepath,
+            dpi=dpi,
+            orbit_and_frame=orbit_and_frame,
+            utc_timestamp=utc_timestamp,
+            use_utc_creation_timestamp=use_utc_creation_timestamp,
+            site_name=site_name,
+            hmax=hmax,
+            radius=radius,
+            extra=extra,
+            transparent_outside=transparent_outside,
+            verbose=verbose,
+            print_prefix=print_prefix,
+            create_dirs=create_dirs,
+            transparent_background=transparent_background,
+            resolution=resolution,
+            **kwargs,
+        )
