@@ -37,7 +37,11 @@ from owslib.wms import WebMapService  # type: ignore
 
 from ...utils import GroundSite, all_in, get_ground_site
 from ...utils.constants import *
-from ...utils.constants import FIGURE_MAP_HEIGHT, FIGURE_MAP_WIDTH
+from ...utils.constants import (
+    DEFAULT_COLORBAR_WIDTH,
+    FIGURE_MAP_HEIGHT,
+    FIGURE_MAP_WIDTH,
+)
 from ...utils.geo import get_coord_between, get_coords, haversine
 from ...utils.geo.bbox import compute_bbox, pad_bbox
 from ...utils.geo.coordinates import (
@@ -68,7 +72,8 @@ from ...utils.typing import ValueRangeLike, validate_numeric_pair
 from ...utils.xarray_utils import filter_radius, filter_time
 from ..color import Cmap, Color, ColorLike, get_cmap
 from ..save import save_plot
-from ..text import shade_around_text
+from ..text import add_shade_to_text
+from ._ensure_updated_msi_rgb_if_required import ensure_updated_msi_rgb_if_required
 from .annotation import (
     add_text,
     add_text_overpass_info,
@@ -76,7 +81,7 @@ from .annotation import (
     add_title_earthcare_time,
     format_var_label,
 )
-from .colorbar import add_colorbar, add_vertical_colorbar
+from .colorbar import add_colorbar
 from .defaults import get_default_cmap, get_default_norm, get_default_rolling_mean
 
 
@@ -190,8 +195,10 @@ def set_view(
     ymin = y.min()
     ymax = y.max()
     yd = np.abs(ymax - ymin)
-    ax.set_xlim(xmin - xd * pad_xmin, xmax + xd * pad_xmax)
-    ax.set_ylim(ymin - yd * pad_ymin, ymax + yd * pad_ymax)
+    xlim = (xmin - xd * pad_xmin, xmax + xd * pad_xmax)
+    ylim = (ymin - yd * pad_ymin, ymax + yd * pad_ymax)
+    ax.set_xlim(*xlim)
+    ax.set_ylim(*ylim)
 
     return ax
 
@@ -317,7 +324,17 @@ class MapFigure:
         dpi: int | None = None,
         title: str | None = None,
         style: (
-            str | Literal["none", "stock_img", "gray", "osm", "satellite", "mtg", "msg"]
+            str
+            | Literal[
+                "none",
+                "stock_img",
+                "gray",
+                "osm",
+                "satellite",
+                "mtg",
+                "msg",
+                "blue_marble",
+            ]
         ) = "gray",
         projection: (
             Literal["platecarree", "perspective", "orthographic"] | ccrs.Projection
@@ -346,7 +363,10 @@ class MapFigure:
         pad: float | list[float] = 0.05,
         background_alpha: float = 1.0,
         colorbar_tick_scale: float | None = None,
+        fig_height_scale: float = 1.0,
+        fig_width_scale: float = 1.0,
     ):
+        figsize = (figsize[0] * fig_width_scale, figsize[1] * fig_height_scale)
         self.figsize = _validate_figsize(figsize)
         self.fig, self.ax = _ensure_figure_and_main_axis(ax, figsize=figsize, dpi=dpi)
 
@@ -537,6 +557,26 @@ class MapFigure:
             )  # type: ignore
             grid_color = Color("#C0C0C099")
             coastline_color = Color("#C0C0C099")
+        elif self.style == "blue_marble":
+
+            wms = WebMapService(
+                "https://gibs.earthdata.nasa.gov/wms/epsg4326/best/wms.cgi?",
+                version="1.1.1",
+            )
+            layer = "BlueMarble_ShadedRelief_Bathymetry"
+            self.ax.add_wms(wms, layer)  # type: ignore
+            grid_color = Color("#C7C7C799")
+            coastline_color = Color("ec:lightblue")
+
+            width, height = 1024, 512
+            white_overlay = np.ones((height, width, 4))
+            white_overlay[..., 3] = 0.2
+
+            self.ax.imshow(
+                white_overlay,
+                origin="upper",
+                transform=ccrs.PlateCarree(),
+            )
         else:
             if not isinstance(self.timestamp, pd.Timestamp):
                 msg = f"Missing timestamp for {self.style.upper()} data request for 'https://view.eumetsat.int' (timestamp={self.timestamp})"
@@ -574,6 +614,13 @@ class MapFigure:
                         version="1.1.1",
                     )
                     layer = "MODIS_Terra_CorrectedReflectance_TrueColor"
+                elif "nasa:" in self.style:
+                    self.style = self.style.replace("nasa:", "")
+                    layer = self.style
+                    wms = WebMapService(
+                        "https://gibs.earthdata.nasa.gov/wms/epsg4326/best/wms.cgi?",
+                        version="1.1.1",
+                    )
                 else:
                     layer = self.style
                     # raise NotImplementedError()
@@ -583,17 +630,17 @@ class MapFigure:
 
                 self.ax.add_wms(wms, layer, wms_kwargs=wms_kwargs)  # type: ignore
 
-                # Overlay white transparent layer
-                if self.background_alpha < 1.0:
-                    width, height = 1024, 512
-                    white_overlay = np.ones((height, width, 4))
-                    white_overlay[..., 3] = 1 - self.background_alpha
+        # Overlay white transparent layer
+        if self.background_alpha < 1.0:
+            width, height = 1024, 512
+            white_overlay = np.ones((height, width, 4))
+            white_overlay[..., 3] = 1 - self.background_alpha
 
-                    self.ax.imshow(
-                        white_overlay,
-                        origin="upper",
-                        transform=ccrs.PlateCarree(),
-                    )
+            self.ax.imshow(
+                white_overlay,
+                origin="upper",
+                transform=ccrs.PlateCarree(),
+            )
         # else:
         #     raise ValueError(
         #         f'invalid style "{self.style}". Valid styles are: "gray", "osm", "satellite"'
@@ -670,12 +717,14 @@ class MapFigure:
         border_linewidth: float = 1,
         border_color="black",
         colorbar: bool = True,
-        cb_orientation: str | Literal["vertical", "horizontal"] = "horizontal",
-        cb_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
-        cb_alignment: str | Literal["left", "center", "right"] = "center",
-        cb_buffer: float = 1.02,
-        cb_width_ratio: float | str = "2%",
-        cb_height_ratio: float | str = "100%",
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.3,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         label: str = "",
         units: str = "",
         line_overlap: int = 20,
@@ -743,18 +792,23 @@ class MapFigure:
             self.ax.add_collection(_lc)
 
             if colorbar and not self.colorbar:
-                self.colorbar = add_colorbar(
-                    self.fig,
-                    self.ax,
-                    _lc,
-                    orientation=cb_orientation,
-                    position=cb_position,
-                    alignment=cb_alignment,
-                    buffer=cb_buffer,
-                    width_ratio=cb_width_ratio,
-                    height_ratio=cb_height_ratio,
+                cb_kwargs = dict(
                     label=format_var_label(label, units),
+                    position=colorbar_position,
+                    alignment=colorbar_alignment,
+                    width=colorbar_width,
+                    spacing=colorbar_spacing,
+                    length_ratio=colorbar_length_ratio,
+                    label_outside=colorbar_label_outside,
+                    ticks_outside=colorbar_ticks_outside,
+                    ticks_both=colorbar_ticks_both,
+                )
+                self.colorbar = add_colorbar(
+                    fig=self.fig,
+                    ax=self.ax,
+                    data=_lc,
                     cmap=cmap,
+                    **cb_kwargs,  # type: ignore
                 )
                 self.set_colorbar_tick_scale(multiplier=self.colorbar_tick_scale)
 
@@ -867,16 +921,19 @@ class MapFigure:
             rotation=rotation,
             rotation_mode="anchor",
         )
-        t = shade_around_text(t)
+        t = add_shade_to_text(t)
         return self
 
     def plot_point(
         self,
         latitude: int | float,
         longitude: int | float,
-        marker: str | None = "s",
+        marker: str | None = "D",
         markersize: int | float = 5,
         color: Color | ColorLike | None = "black",
+        alpha: float = 1.0,
+        edgecolor: Color | ColorLike | None = "white",
+        edgealpha: float = 0.8,
         zorder: int | float = 4,
         text: str | None = None,
         text_color: Color | ColorLike | None = "black",
@@ -884,6 +941,8 @@ class MapFigure:
         text_zorder: int | float = 8,
         text_padding: str = "  ",
     ) -> "MapFigure":
+        _color = Color.from_optional(color, alpha=alpha)
+        _edgecolor = Color.from_optional(edgecolor, alpha=edgealpha)
         self.ax.plot(
             [longitude],
             [latitude],
@@ -891,8 +950,10 @@ class MapFigure:
             markersize=markersize,
             linestyle="none",
             transform=self.transform,
-            color=color,
+            color=_color,
             zorder=zorder,
+            markerfacecolor=_color,
+            markeredgecolor=_edgecolor,
         )
         if isinstance(text, str):
             self.plot_text(
@@ -915,10 +976,11 @@ class MapFigure:
         face_color: Color | ColorLike | None = "#FFFFFF00",
         edge_color: Color | ColorLike | None = None,
         text_color: Color | ColorLike | None = None,
+        point_color: Color | ColorLike | None = None,
         edge_alpha: float = 0.8,
         text: str | None = None,
         text_side: Literal["left", "right"] = "right",
-        marker: str | None = "s",
+        marker: str | None = "D",
         zorder: int | float = 4,
         text_zorder: int | float = 8,
     ) -> "MapFigure":
@@ -926,6 +988,7 @@ class MapFigure:
         _face_color = Color.from_optional(face_color) or Color("#FFFFFF00")
         _edge_color = Color.from_optional(edge_color) or _color
         _text_color = Color.from_optional(text_color) or Color("#000000")
+        _point_color = Color.from_optional(point_color) or _color
         if isinstance(_edge_color, Color):
             _edge_color = _edge_color.set_alpha(edge_alpha)
 
@@ -951,7 +1014,7 @@ class MapFigure:
             latitude=latitude,
             marker=marker,
             markersize=5,
-            color=_color,
+            color=_point_color,
             zorder=zorder,
             text=text,
             text_color=_text_color,
@@ -970,6 +1033,7 @@ class MapFigure:
         lon_total: NDArray,
         site: GroundSite,
         radius_km: int | float,
+        site_color: Color | ColorLike | None = "black",
         radius_color: Color | ColorLike | None = None,
         color_selection: Color | ColorLike | None = "ec:earthcare",
         linewidth_selection: float = 3,
@@ -983,8 +1047,10 @@ class MapFigure:
         show_highlights: bool = True,
     ) -> "MapFigure":
         if radius_color is None:
-            if self.style == "satellite":
+            if self.style in ["satellite", "blue_marble"]:
                 radius_color = "white"
+            elif self.style in ["gray"]:
+                radius_color = "black"
 
         lat_selection = np.asarray(lat_selection)
         lon_selection = np.asarray(lon_selection)
@@ -1031,6 +1097,8 @@ class MapFigure:
             text=site_name,
             text_side=site_text_side,
             color=radius_color,
+            point_color=site_color,
+            text_color=site_color,
         )
 
         highlight_last = False if view == "overpass" else True
@@ -1071,7 +1139,58 @@ class MapFigure:
                 self.ax.set_xlim(-zoom_radius_meters, zoom_radius_meters)
                 self.ax.set_ylim(-zoom_radius_meters, zoom_radius_meters)
         elif view == "data":
-            self.set_view(lats=lat_total, lons=lon_total)
+            _lats = lat_total
+            is_polar_track: bool = not ismonotonic(lat_total)
+            if is_polar_track:
+                _lats = np.nanmin(_lats)
+            if isinstance(self.projection, ccrs.PlateCarree) or not is_polar_track:
+                self.set_view(lats=_lats, lons=lon_total)
+            else:
+                _dist = haversine(
+                    (self.central_latitude, self.central_longitude),
+                    (lat_total[0], lon_total[0]),
+                    units="m",
+                )
+
+                _dist2 = haversine(
+                    (self.central_latitude, self.central_longitude),
+                    (lat_total[-1], lon_total[-1]),
+                    units="m",
+                )
+                _ratio = np.max([(_dist / np.max([_dist2, 1.0])) * 0.5, 1.0])
+
+                self.ax.set_xlim(-_dist / _ratio, _dist / _ratio)
+                if lat_total[0] < lat_total[1]:
+                    self.ax.set_ylim(-_dist / _ratio, _dist)
+                else:
+                    self.ax.set_ylim(-_dist, _dist / _ratio)
+
+            # zoom_radius_meters = (
+            #     haversine(
+            #         (lat_total[0], lon_total[0]),
+            #         (lat_total[-1], lon_total[-1]),
+            #         units="m",
+            #     )
+            #     * 1.3
+            # ) / 2
+            # if isinstance(self.projection, ccrs.PlateCarree):
+            #     self.set_view(lats=lat_total, lons=lon_total)
+            # else:
+            #     self.ax.set_xlim(-zoom_radius_meters, zoom_radius_meters)
+            #     self.ax.set_ylim(-zoom_radius_meters, zoom_radius_meters)
+
+            # _diameter = haversine(
+            #     (lat_total[0], lon_total[0]),
+            #     (lat_total[-1], lon_total[-1]),
+            #     units="m",
+            # )
+            # _radius = _diameter / 2
+            # zoom_radius_meters = _radius * 1e3 * 1.3
+            # if isinstance(self.projection, ccrs.PlateCarree):
+            #     self.set_view(lats=lat_total, lons=lon_total)
+            # else:
+            #     self.ax.set_xlim(-zoom_radius_meters, zoom_radius_meters)
+            #     self.ax.set_ylim(-zoom_radius_meters, zoom_radius_meters)
 
         return self
 
@@ -1104,7 +1223,7 @@ class MapFigure:
         extent: list[float] | None = None,
         central_latitude: float | None = None,
         central_longitude: float | None = None,
-        value_range: ValueRangeLike | None = None,
+        value_range: ValueRangeLike | Literal["default"] | None = "default",
         log_scale: bool | None = None,
         norm: Normalize | None = None,
         colorbar: bool = True,
@@ -1112,12 +1231,14 @@ class MapFigure:
         show_text_time: bool | None = None,
         show_text_frame: bool | None = None,
         show_text_overpass: bool | None = None,
-        cb_orientation: str | Literal["vertical", "horizontal"] = "horizontal",
-        cb_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
-        cb_alignment: str | Literal["left", "center", "right"] = "center",
-        cb_buffer: float = 1.02,
-        cb_width_ratio: float | str = "2%",
-        cb_height_ratio: float | str = "100%",
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.3,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         selection_max_time_margin: (
             TimedeltaLike | Sequence[TimedeltaLike] | None
         ) = None,
@@ -1165,12 +1286,6 @@ class MapFigure:
             show_text_time (bool | None, optional): Whether to display the UTC time start and end of the selected track. Defaults to None.
             show_text_frame (bool | None, optional): Whether to display EarthCARE frame information. Defaults to None.
             show_text_overpass (bool | None, optional): Whether to display overpass site name and related info. Defaults to None.
-            cb_orientation (Literal["vertical", "horizontal"], optional): Orientation of the colorbar. Defaults to "horizontal".
-            cb_position (Literal["left", "right", "top", "bottom"], optional): Position of the colorbar in the plot. Defaults to "bottom".
-            cb_alignment (Literal["left", "center", "right"], optional): Horizontal alignment of the colorbar relative to the plot. Defaults to "center".
-            cb_buffer (float, optional): Distance between plot and colorbar in axes units. Defaults to 1.02.
-            cb_width_ratio (float | str, optional): Width of the colorbar relative to the plot area. Defaults to "2.5%".
-            cb_height_ratio (float | str, optional): Height of the colorbar relative to the plot area. Defaults to "100%".
 
         Returns:
             MapFigure: The figure object containing the map with track or swath.
@@ -1205,6 +1320,9 @@ class MapFigure:
             _linewidth2 = linewidth * 0.7
 
         if isinstance(var, str):
+            ds = ensure_updated_msi_rgb_if_required(
+                ds, var, time_range, time_var=time_var
+            )
             _linewidth = linewidth * 0.5
             linestyle = "dashed"
             _linewidth2 = linewidth * 0.2
@@ -1239,6 +1357,8 @@ class MapFigure:
             coords_zoomed_in = coords_whole_flight
             coords_zoomed_in_track = get_coords(ds, lat_var=lat_var, lon_var=lon_var)
 
+        is_polar_track: bool = False
+
         if isinstance(_site, GroundSite):
             ds_overpass = filter_radius(
                 ds,
@@ -1307,6 +1427,7 @@ class MapFigure:
                 linestyle_total=linestyle2,
                 show_highlights=view == "overpass"
                 or not isinstance(_selection_max_time_margin, tuple),
+                radius_color=None,
             )
 
             if isinstance(_selection_max_time_margin, tuple):
@@ -1337,6 +1458,7 @@ class MapFigure:
                 self.central_longitude = central_longitude
             else:
                 if not ismonotonic(coords_whole_flight[:, 0]):
+                    is_polar_track = True
                     self.central_longitude = coords_whole_flight[-1, 1]
                 else:
                     self.central_longitude = circular_nanmean(coords_whole_flight[:, 1])
@@ -1392,11 +1514,43 @@ class MapFigure:
             if view == "global":
                 self.ax.set_global()  # type: ignore
             elif view == "data":
-                self.set_view(
-                    lats=coords_whole_flight[:, 0], lons=coords_whole_flight[:, 1]
-                )
+                _lats = coords_whole_flight[:, 0]
+                if is_polar_track:
+                    _lats = np.nanmin(_lats)
+                if isinstance(self.projection, ccrs.PlateCarree) or not is_polar_track:
+                    self.set_view(lats=_lats, lons=coords_whole_flight[:, 1])
+                else:
+                    _dist = haversine(
+                        (self.central_latitude, self.central_longitude),  # type: ignore
+                        coords_whole_flight[0],
+                        units="m",
+                    )
+                    self.ax.set_xlim(-_dist / 2, _dist / 2)
+                    if coords_whole_flight[0, 0] < coords_whole_flight[1, 0]:
+                        self.ax.set_ylim(-_dist / 2, _dist)
+                    else:
+                        self.ax.set_ylim(-_dist, _dist / 2)
             else:
-                self.set_view(lats=coords_zoomed_in[:, 0], lons=coords_zoomed_in[:, 1])
+                _lats = coords_zoomed_in[:, 0]
+                if is_polar_track:
+                    _lats = np.nanmin(_lats)
+                if isinstance(self.projection, ccrs.PlateCarree) or not is_polar_track:
+                    self.set_view(lats=_lats, lons=coords_zoomed_in[:, 1])
+                else:
+                    _dist = haversine(
+                        (self.central_latitude, self.central_longitude),  # type: ignore
+                        coords_zoomed_in[0],
+                        units="m",
+                    )
+                    self.ax.set_xlim(-_dist / 2, _dist / 2)
+                    if coords_zoomed_in[0, 0] < coords_zoomed_in[1, 0]:
+                        self.ax.set_ylim(-_dist / 2, _dist)
+                    else:
+                        self.ax.set_ylim(-_dist, _dist / 2)
+                # _lats = coords_zoomed_in[:, 0]
+                # if is_polar_track:
+                #     _lats = np.nanmin(_lats)
+                # self.set_view(lats=_lats, lons=coords_zoomed_in[:, 1])
 
             if self.show_text_time:
                 add_title_earthcare_time(self.ax, ds=ds, tmin=zoom_tmin, tmax=zoom_tmax)
@@ -1404,8 +1558,10 @@ class MapFigure:
         if isinstance(var, str):
             if cmap is None:
                 cmap = get_default_cmap(var, ds)
-            if norm is None:
-                norm = get_default_norm(var, ds)
+            if isinstance(value_range, str) and value_range == "default":
+                value_range = None
+                if log_scale is None and norm is None:
+                    norm = get_default_norm(var, file_type=ds)
             lats = ds[swath_lat_var].values
             lons = ds[swath_lon_var].values
             values = ds[var].values
@@ -1422,12 +1578,14 @@ class MapFigure:
                 log_scale=log_scale,
                 norm=norm,
                 colorbar=colorbar,
-                cb_orientation=cb_orientation,
-                cb_position=cb_position,
-                cb_alignment=cb_alignment,
-                cb_buffer=cb_buffer,
-                cb_width_ratio=cb_width_ratio,
-                cb_height_ratio=cb_height_ratio,
+                colorbar_position=colorbar_position,
+                colorbar_alignment=colorbar_alignment,
+                colorbar_width=colorbar_width,
+                colorbar_spacing=colorbar_spacing,
+                colorbar_length_ratio=colorbar_length_ratio,
+                colorbar_label_outside=colorbar_label_outside,
+                colorbar_ticks_outside=colorbar_ticks_outside,
+                colorbar_ticks_both=colorbar_ticks_both,
             )
 
         # if view == "data":
@@ -1494,12 +1652,14 @@ class MapFigure:
         log_scale: bool | None = None,
         norm: Normalize | None = None,
         colorbar: bool = True,
-        cb_orientation: str | Literal["vertical", "horizontal"] = "horizontal",
-        cb_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
-        cb_alignment: str | Literal["left", "center", "right"] = "center",
-        cb_buffer: float = 1.02,
-        cb_width_ratio: float | str = "2.5%",
-        cb_height_ratio: float | str = "100%",
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.3,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         show_swath_border: bool = True,
     ) -> "MapFigure":
         cmap, value_range, norm = self._init_cmap(cmap, value_range, log_scale, norm)
@@ -1511,6 +1671,7 @@ class MapFigure:
                 values,
                 shading="auto",
                 transform=ccrs.PlateCarree(),
+                rasterized=True,
             )
         else:
             mesh = self.ax.pcolormesh(
@@ -1521,20 +1682,26 @@ class MapFigure:
                 norm=norm,
                 shading="auto",
                 transform=ccrs.PlateCarree(),
+                rasterized=True,
             )
             if colorbar:
-                self.colorbar = add_colorbar(
-                    self.fig,
-                    self.ax,
-                    mesh,
-                    orientation=cb_orientation,
-                    position=cb_position,
-                    alignment=cb_alignment,
-                    buffer=cb_buffer,
-                    width_ratio=cb_width_ratio,
-                    height_ratio=cb_height_ratio,
+                cb_kwargs = dict(
                     label=format_var_label(label, units),
+                    position=colorbar_position,
+                    alignment=colorbar_alignment,
+                    width=colorbar_width,
+                    spacing=colorbar_spacing,
+                    length_ratio=colorbar_length_ratio,
+                    label_outside=colorbar_label_outside,
+                    ticks_outside=colorbar_ticks_outside,
+                    ticks_both=colorbar_ticks_both,
+                )
+                self.colorbar = add_colorbar(
+                    fig=self.fig,
+                    ax=self.ax,
+                    data=mesh,
                     cmap=cmap,
+                    **cb_kwargs,  # type: ignore
                 )
                 self.set_colorbar_tick_scale(multiplier=self.colorbar_tick_scale)
         if show_swath_border:
@@ -1688,9 +1855,83 @@ class MapFigure:
             cb.ax.tick_params(labelsize=_fontsize * multiplier)
         return self
 
-    def show(self):
-        self.fig.tight_layout()
-        self.fig.show()
+    def show(self) -> None:
+        import IPython
+        import matplotlib.pyplot as plt
+        from IPython.display import display
 
-    def save(self, filename: str = "", filepath: str | None = None, **kwargs):
-        save_plot(fig=self.fig, filename=filename, filepath=filepath, **kwargs)
+        if IPython.get_ipython() is not None:
+            display(self.fig)
+        else:
+            plt.show()
+
+    def save(
+        self,
+        filename: str = "",
+        filepath: str | None = None,
+        ds: xr.Dataset | None = None,
+        ds_filepath: str | None = None,
+        dpi: float | Literal["figure"] = "figure",
+        orbit_and_frame: str | None = None,
+        utc_timestamp: TimestampLike | None = None,
+        use_utc_creation_timestamp: bool = False,
+        site_name: str | None = None,
+        hmax: int | float | None = None,
+        radius: int | float | None = None,
+        extra: str | None = None,
+        transparent_outside: bool = False,
+        verbose: bool = True,
+        print_prefix: str = "",
+        create_dirs: bool = False,
+        transparent_background: bool = False,
+        resolution: str | None = None,
+        **kwargs,
+    ) -> None:
+        """
+        Save a figure as an image or vector graphic to a file and optionally format the file name in a structured way using EarthCARE metadata.
+
+        Args:
+            figure (Figure | HasFigure): A figure object (`matplotlib.figure.Figure`) or objects exposing a `.fig` attribute containing a figure (e.g., `CurtainFigure`).
+            filename (str, optional): The base name of the file. Can be extended based on other metadata provided. Defaults to empty string.
+            filepath (str | None, optional): The path where the image is saved. Can be extended based on other metadata provided. Defaults to None.
+            ds (xr.Dataset | None, optional): A EarthCARE dataset from which metadata will be taken. Defaults to None.
+            ds_filepath (str | None, optional): A path to a EarthCARE product from which metadata will be taken. Defaults to None.
+            pad (float, optional): Extra padding (i.e., empty space) around the image in inches. Defaults to 0.1.
+            dpi (float | 'figure', optional): The resolution in dots per inch. If 'figure', use the figure's dpi value. Defaults to None.
+            orbit_and_frame (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            utc_timestamp (TimestampLike | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            use_utc_creation_timestamp (bool, optional): Whether the time of image creation should be included in the file name. Defaults to False.
+            site_name (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            hmax (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            radius (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            resolution (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            extra (str | None, optional): A custom string to be included in the file name. Defaults to None.
+            transparent_outside (bool, optional): Whether the area outside figures should be transparent. Defaults to False.
+            verbose (bool, optional): Whether the progress of image creation should be printed to the console. Defaults to True.
+            print_prefix (str, optional): A prefix string to all console messages. Defaults to "".
+            create_dirs (bool, optional): Whether images should be saved in a folder structure based on provided metadata. Defaults to False.
+            transparent_background (bool, optional): Whether the background inside and outside of figures should be transparent. Defaults to False.
+            **kwargs (dict[str, Any]): Keyword arguments passed to wrapped function call of `matplotlib.pyplot.savefig`.
+        """
+        save_plot(
+            fig=self.fig,
+            filename=filename,
+            filepath=filepath,
+            ds=ds,
+            ds_filepath=ds_filepath,
+            dpi=dpi,
+            orbit_and_frame=orbit_and_frame,
+            utc_timestamp=utc_timestamp,
+            use_utc_creation_timestamp=use_utc_creation_timestamp,
+            site_name=site_name,
+            hmax=hmax,
+            radius=radius,
+            extra=extra,
+            transparent_outside=transparent_outside,
+            verbose=verbose,
+            print_prefix=print_prefix,
+            create_dirs=create_dirs,
+            transparent_background=transparent_background,
+            resolution=resolution,
+            **kwargs,
+        )
