@@ -17,23 +17,22 @@ from numpy.typing import ArrayLike, NDArray
 
 from ...utils.constants import *
 from ...utils.constants import FIGURE_HEIGHT_SWATH, FIGURE_WIDTH_SWATH
-from ...utils.profile_data import (
-    ProfileData,
-    ensure_along_track_2d,
-    ensure_vertical_2d,
-    validate_profile_data_dimensions,
-)
 from ...utils.swath_data import SwathData
 from ...utils.swath_data.across_track_distance import get_nadir_index
-from ...utils.time import TimeRangeLike, to_timestamp, validate_time_range
+from ...utils.time import (
+    TimeRangeLike,
+    TimestampLike,
+    to_timestamp,
+    validate_time_range,
+)
 from ...utils.typing import DistanceRangeLike, ValueRangeLike
 from ..color import Cmap, Color, ColorLike, get_cmap
 from ..save import save_plot
+from ._ensure_updated_msi_rgb_if_required import ensure_updated_msi_rgb_if_required
 from .along_track import AlongTrackAxisStyle, format_along_track_axis
 from .annotation import add_text_product_info, format_var_label
-from .axis import format_label
-from .colorbar import add_vertical_colorbar
-from .defaults import get_default_cmap, get_default_norm, get_default_rolling_mean
+from .colorbar import add_colorbar
+from .defaults import get_default_cmap, get_default_norm
 from .height_ticks import format_height_ticks
 
 logger = logging.getLogger(__name__)
@@ -57,7 +56,10 @@ class SwathFigure:
             "across_track_distance",
             "pixel",
         ] = "from_track_distance",
+        fig_height_scale: float = 1.0,
+        fig_width_scale: float = 1.0,
     ):
+        figsize = (figsize[0] * fig_width_scale, figsize[1] * fig_height_scale)
         self.fig: Figure
         if isinstance(ax, Axes):
             tmp = ax.get_figure()
@@ -119,6 +121,14 @@ class SwathFigure:
         colorbar: bool = True,
         colorbar_ticks: ArrayLike | None = None,
         colorbar_tick_labels: ArrayLike | None = None,
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "right",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.2,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         selection_time_range: TimeRangeLike | None = None,
         selection_color: str | None = Color("ec:earthcare"),
         selection_linestyle: str | None = "dashed",
@@ -256,7 +266,13 @@ class SwathFigure:
         tmax = np.datetime64(time_range[1])
 
         if len(values.shape) == 3 and values.shape[2] == 3:
-            mesh = self.ax.pcolormesh(time, ydata, values, **kwargs)
+            mesh = self.ax.pcolormesh(
+                time,
+                ydata,
+                values,
+                rasterized=True,
+                **kwargs,
+            )
         else:
             mesh = self.ax.pcolormesh(
                 time,
@@ -264,26 +280,38 @@ class SwathFigure:
                 values.T,
                 norm=norm,
                 cmap=cmap,
+                rasterized=True,
                 **kwargs,
             )
 
             if colorbar:
+                cb_kwargs = dict(
+                    label=format_var_label(label, units, label_len=label_length),
+                    position=colorbar_position,
+                    alignment=colorbar_alignment,
+                    width=colorbar_width,
+                    spacing=colorbar_spacing,
+                    length_ratio=colorbar_length_ratio,
+                    label_outside=colorbar_label_outside,
+                    ticks_outside=colorbar_ticks_outside,
+                    ticks_both=colorbar_ticks_both,
+                )
                 if cmap.categorical:
-                    self.colorbar = add_vertical_colorbar(
+                    self.colorbar = add_colorbar(
                         fig=self.fig,
                         ax=self.ax,
                         data=mesh,
-                        label=format_var_label(label, units, label_len=label_length),
                         cmap=cmap,
+                        **cb_kwargs,  # type: ignore
                     )
                 else:
-                    self.colorbar = add_vertical_colorbar(
+                    self.colorbar = add_colorbar(
                         fig=self.fig,
                         ax=self.ax,
                         data=mesh,
-                        label=format_var_label(label, units, label_len=label_length),
                         ticks=colorbar_ticks,
                         tick_labels=colorbar_tick_labels,
+                        **cb_kwargs,  # type: ignore
                     )
 
         if selection_time_range is not None:
@@ -320,7 +348,19 @@ class SwathFigure:
                 )  # type: ignore
 
         if show_nadir:
-            self.ax.axhline(
+            nadir_color = Color.from_optional(nadir_color)
+            nadir_color_shade = "white"
+            if isinstance(nadir_color, Color):
+                nadir_color_shade = nadir_color.get_best_bw_contrast_color()
+            nadir_line_shade = self.ax.axhline(
+                y=ynadir,
+                color=nadir_color_shade,
+                linestyle="solid",
+                linewidth=nadir_linewidth * 2,
+                alpha=0.3,
+                zorder=10,
+            )
+            nadir_line = self.ax.axhline(
                 y=ynadir,
                 color=Color.from_optional(nadir_color),
                 linestyle="dashed",
@@ -513,7 +553,7 @@ class SwathFigure:
         show_info: bool = True,
         info_text_loc: str | None = None,
         # Common args for wrappers
-        value_range: ValueRangeLike | None = None,
+        value_range: ValueRangeLike | Literal["default"] | None = "default",
         log_scale: bool | None = None,
         norm: Normalize | None = None,
         time_range: TimeRangeLike | None = None,
@@ -524,6 +564,14 @@ class SwathFigure:
         colorbar: bool = True,
         colorbar_ticks: ArrayLike | None = None,
         colorbar_tick_labels: ArrayLike | None = None,
+        colorbar_position: str | Literal["left", "right", "top", "bottom"] = "right",
+        colorbar_alignment: str | Literal["left", "center", "right"] = "center",
+        colorbar_width: float = DEFAULT_COLORBAR_WIDTH,
+        colorbar_spacing: float = 0.2,
+        colorbar_length_ratio: float | str = "100%",
+        colorbar_label_outside: bool = True,
+        colorbar_ticks_outside: bool = True,
+        colorbar_ticks_both: bool = False,
         selection_time_range: TimeRangeLike | None = None,
         selection_color: str | None = Color("ec:earthcare"),
         selection_linestyle: str | None = "dashed",
@@ -576,11 +624,16 @@ class SwathFigure:
             )
         if units is None:
             all_args["units"] = "-" if not hasattr(ds[var], "units") else ds[var].units
-        if value_range is None and log_scale is None and norm is None:
-            all_args["norm"] = get_default_norm(var)
+        if isinstance(value_range, str) and value_range == "default":
+            value_range = None
+            all_args["value_range"] = None
+            if log_scale is None and norm is None:
+                all_args["norm"] = get_default_norm(var, file_type=ds)
         if cmap is None:
             all_args["cmap"] = get_default_cmap(var, file_type=ds)
 
+        ds = ensure_updated_msi_rgb_if_required(ds, var, time_range, time_var=time_var)
+
         self.plot(**all_args)
 
         self._set_info_text_loc(info_text_loc)
@@ -654,9 +707,83 @@ class SwathFigure:
             cb.ax.tick_params(labelsize=_fontsize * multiplier)
         return self
 
-    def show(self):
-        self.fig.tight_layout()
-        self.fig.show()
+    def show(self) -> None:
+        import IPython
+        import matplotlib.pyplot as plt
+        from IPython.display import display
 
-    def save(self, filename: str = "", filepath: str | None = None, **kwargs):
-        save_plot(fig=self.fig, filename=filename, filepath=filepath, **kwargs)
+        if IPython.get_ipython() is not None:
+            display(self.fig)
+        else:
+            plt.show()
+
+    def save(
+        self,
+        filename: str = "",
+        filepath: str | None = None,
+        ds: xr.Dataset | None = None,
+        ds_filepath: str | None = None,
+        dpi: float | Literal["figure"] = "figure",
+        orbit_and_frame: str | None = None,
+        utc_timestamp: TimestampLike | None = None,
+        use_utc_creation_timestamp: bool = False,
+        site_name: str | None = None,
+        hmax: int | float | None = None,
+        radius: int | float | None = None,
+        extra: str | None = None,
+        transparent_outside: bool = False,
+        verbose: bool = True,
+        print_prefix: str = "",
+        create_dirs: bool = False,
+        transparent_background: bool = False,
+        resolution: str | None = None,
+        **kwargs,
+    ) -> None:
+        """
+        Save a figure as an image or vector graphic to a file and optionally format the file name in a structured way using EarthCARE metadata.
+
+        Args:
+            figure (Figure | HasFigure): A figure object (`matplotlib.figure.Figure`) or objects exposing a `.fig` attribute containing a figure (e.g., `CurtainFigure`).
+            filename (str, optional): The base name of the file. Can be extended based on other metadata provided. Defaults to empty string.
+            filepath (str | None, optional): The path where the image is saved. Can be extended based on other metadata provided. Defaults to None.
+            ds (xr.Dataset | None, optional): A EarthCARE dataset from which metadata will be taken. Defaults to None.
+            ds_filepath (str | None, optional): A path to a EarthCARE product from which metadata will be taken. Defaults to None.
+            pad (float, optional): Extra padding (i.e., empty space) around the image in inches. Defaults to 0.1.
+            dpi (float | 'figure', optional): The resolution in dots per inch. If 'figure', use the figure's dpi value. Defaults to None.
+            orbit_and_frame (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            utc_timestamp (TimestampLike | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            use_utc_creation_timestamp (bool, optional): Whether the time of image creation should be included in the file name. Defaults to False.
+            site_name (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            hmax (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            radius (int | float | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            resolution (str | None, optional): Metadata used in the formatting of the file name. Defaults to None.
+            extra (str | None, optional): A custom string to be included in the file name. Defaults to None.
+            transparent_outside (bool, optional): Whether the area outside figures should be transparent. Defaults to False.
+            verbose (bool, optional): Whether the progress of image creation should be printed to the console. Defaults to True.
+            print_prefix (str, optional): A prefix string to all console messages. Defaults to "".
+            create_dirs (bool, optional): Whether images should be saved in a folder structure based on provided metadata. Defaults to False.
+            transparent_background (bool, optional): Whether the background inside and outside of figures should be transparent. Defaults to False.
+            **kwargs (dict[str, Any]): Keyword arguments passed to wrapped function call of `matplotlib.pyplot.savefig`.
+        """
+        save_plot(
+            fig=self.fig,
+            filename=filename,
+            filepath=filepath,
+            ds=ds,
+            ds_filepath=ds_filepath,
+            dpi=dpi,
+            orbit_and_frame=orbit_and_frame,
+            utc_timestamp=utc_timestamp,
+            use_utc_creation_timestamp=use_utc_creation_timestamp,
+            site_name=site_name,
+            hmax=hmax,
+            radius=radius,
+            extra=extra,
+            transparent_outside=transparent_outside,
+            verbose=verbose,
+            print_prefix=print_prefix,
+            create_dirs=create_dirs,
+            transparent_background=transparent_background,
+            resolution=resolution,
+            **kwargs,
+        )
