@@ -9,8 +9,8 @@ from ...utils.constants import CM_AS_INCH, FIGURE_HEIGHT_CURTAIN, FIGURE_WIDTH_C
 from ...utils.read import read_product
 from ...utils.time import to_timestamp
 from ...utils.typing import ValueRangeLike
-from ..color import ColorLike, get_cmap
-from ..figure import MapFigure, create_column_subfigures
+from ..color import Color, ColorLike, get_cmap
+from ..figure import MapFigure, create_column_figure_layout
 
 
 def ecswath(
@@ -24,37 +24,36 @@ def ecswath(
     value_range: ValueRangeLike | None = None,
     show_colorbar: bool = True,
     track_color: ColorLike | None = "black",
+    color_ticks: ColorLike | None = "white",
     linewidth: float = 3.5,
     linestyle: str = "dashed",
     single_figsize: tuple[float, float] = (3, 8),
-    cb_orientation: str | Literal["vertical", "horizontal"] = "horizontal",
+    colorbar_position: str | Literal["left", "right", "top", "bottom"] = "bottom",
 ) -> tuple[Figure, list[MapFigure]]:
     ds = read_product(ds, in_memory=True)
 
-    fig, axs = create_column_subfigures(n, single_figsize=single_figsize)
+    color_ticks = Color.from_optional(color_ticks) or "white"
+
+    _output = create_column_figure_layout(n, single_figsize=single_figsize)
+    fig = _output.fig
+    axs = _output.axs
     tmin = to_timestamp(np.nanmin(ds[time_var].values))
     tmax = to_timestamp(np.nanmax(ds[time_var].values))
     tspan = (tmax - tmin) / n
-    if cb_orientation == "horizontal":
-        cb_buffer = 1.02
-        cb_width_ratio = "2%"
-        cb_position = "bottom"
-        cb_alignment = "center"
+    colorbar_alignment = "center"
+    colorbar_length_ratio = "100%"
+    if colorbar_position in ["top", "bottom"]:
         if n % 2 == 0:
-            cb_alignment = "left"
-        cb_height_ratio = "200%"
-        if n == 1:
-            cb_height_ratio = "100%"
-    else:
-        cb_buffer = 0.05
-        cb_position = "right"
-        cb_alignment = "center"
-        cb_height_ratio = "100%"
-        cb_width_ratio = "5%"
+            colorbar_alignment = "left"
+        if n != 1:
+            colorbar_length_ratio = "200%"
     map_figs: list[MapFigure] = []
+    coastlines_resolution: Literal["10m", "50m", "110m"] = "50m"
+    if n > 3:
+        coastlines_resolution = "10m"
     for i in range(n):
         _show_colorbar = False
-        if cb_orientation == "horizontal":
+        if colorbar_position in ["top", "bottom"]:
             if i == (n - 1) // 2:
                 _show_colorbar = True
         elif i == n - 1:
@@ -75,6 +74,7 @@ def ecswath(
             show_text_time=show_text_time,
             show_text_frame=show_text_frame,
             border_color=border_color,
+            coastlines_resolution=coastlines_resolution,
         )
         p = p.ecplot(
             ds,
@@ -83,13 +83,11 @@ def ecswath(
             zoom_tmin=tmin + i * tspan,
             zoom_tmax=tmin + (i + 1) * tspan,
             colorbar=show_colorbar & _show_colorbar,
-            cb_buffer=cb_buffer,
-            cb_height_ratio=cb_height_ratio,
-            cb_width_ratio=cb_width_ratio,
-            cb_alignment=cb_alignment,
-            cb_orientation=cb_orientation,
-            cb_position=cb_position,
-            cmap=get_cmap(cmap),
+            colorbar_length_ratio=colorbar_length_ratio,
+            colorbar_position=colorbar_position,
+            colorbar_alignment=colorbar_alignment,
+            colorbar_spacing=0.1,
+            cmap=None,
             value_range=value_range,
             color=track_color,
             linewidth=linewidth,
@@ -97,16 +95,17 @@ def ecswath(
         )
         p.grid_lines.ypadding = -3  # type: ignore
         p.grid_lines.ylabel_style = {  # type: ignore
-            "color": "white",
+            "color": color_ticks,
             "fontsize": "small",
             "weight": "bold",
         }
         p.grid_lines.xpadding = -3  # type: ignore
         p.grid_lines.xlabel_style = {  # type: ignore
-            "color": "white",
+            "color": color_ticks,
             "fontsize": "small",
             "weight": "bold",
         }
+        p.grid_lines.zorder = 5  # type: ignore
 
         map_figs.append(p)
     return fig, map_figs
