@@ -104,7 +104,12 @@ def ismonotonic(
         correct_signs.append(0)
 
     if mode == "any":
-        correct_signs.append(signs[0])
+        i: int = 0
+        while i < len(signs) - 1 and signs[i] == 0:
+            i = i + 1
+
+        if signs[i] != 0:
+            correct_signs.append(signs[i])
     elif mode == "increasing":
         correct_signs.append(1)
     elif mode == "decreasing":
@@ -382,7 +387,13 @@ def flatten_array(sequence: ArrayLike) -> NDArray:
         return sequence.flatten()
 
     flattened_sequence = []
-    stack = list(sequence)  # type: ignore
+
+    def _ensure_list(x):
+        if isinstance(x, list):
+            return x.copy()
+        return [x].copy()
+
+    stack = _ensure_list(sequence)  # type: ignore
 
     while stack:
         item = stack.pop(0)
