@@ -1,8 +1,12 @@
 from ._concat import concat_datasets, read_products
 from ._generic import read_product
 from ._header_file import read_hdr_fixed_header
+from ._rebin_msi_to_jsg import rebin_msi_to_jsg
+from ._rebin_xmet_to_vertical_track import rebin_xmet_to_vertical_track
 from ._search import search_product
-from .auxiliary import rebin_xmet_to_vertical_track
+from ._trim_to_frame import trim_to_latitude_frame_bounds
 from .file_info import get_product_infos
 from .header_group import extract_basic_meta_data_from_header, read_header_data
+from .level1.msi_rgr_1c import _add_rgb as update_rgb_of_mrgr
+from .level2a.msi_cop_2a import add_isccp_cloud_type
 from .science_group import read_science_data
