@@ -178,7 +178,8 @@ def is_earthcare_product(filepath: str) -> bool:
 
 def get_product_infos(
     filepaths: str | list[str] | NDArray | pd.DataFrame | xr.Dataset,
-    **kwargs,
+    warn: bool = False,
+    must_exist: bool = True,
 ) -> "ProductDataFrame":
     """
     Extracts product metadata from EarthCARE product file paths (e.g. file_type, orbit_number, frame_id, baseline, ...).
@@ -222,7 +223,9 @@ def get_product_infos(
     infos = []
     for filepath in _filepaths:
         try:
-            infos.append(get_product_info(filepath, **kwargs).to_dict())
+            infos.append(
+                get_product_info(filepath, warn=warn, must_exist=must_exist).to_dict()
+            )
         except ValueError as e:
             continue
     pdf = ProductDataFrame(infos)
@@ -334,6 +337,15 @@ class ProductDataFrame(pd.DataFrame):
         """Retruns filtered `ProductDataFrame` containing only the selected baseline(s)."""
         return self[self["baseline"].isin(np.array(baselines).flatten())]
 
+    def filter_file_type(
+        self, *file_type: str | FileType | list[str | FileType]
+    ) -> "ProductDataFrame":
+        """Retruns filtered `ProductDataFrame` containing only the selected baseline(s)."""
+        _file_types = [
+            str(FileType.from_input(ft)) for ft in np.array(file_type).flatten()
+        ]
+        return self[self["file_type"].isin(_file_types)]
+
     @classmethod
     def from_files(cls, filepaths: list[str]) -> "ProductDataFrame":
         return cls([get_product_info(fp).to_dict() for fp in filepaths])
