@@ -2,30 +2,38 @@ import numpy as np
 import xarray as xr
 
 from ....constants import (
+    DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
     DEFAULT_READ_EC_PRODUCT_HEADER,
     DEFAULT_READ_EC_PRODUCT_META,
     DEFAULT_READ_EC_PRODUCT_MODIFY,
+    SWATH_LAT_VAR,
+    SWATH_LON_VAR,
     UNITS_KELVIN,
     UNITS_MSI_RADIANCE,
 )
 from ....swath_data.across_track_distance import (
     add_across_track_distance,
     add_nadir_track,
+    drop_samples_with_missing_geo_data_along_track,
     get_nadir_index,
 )
 from ....xarray_utils import merge_datasets
 from .._rename_dataset_content import rename_common_dims_and_vars, rename_var_info
 from ..file_info import FileAgency
-from ..header_group import add_header_and_meta_data
 from ..science_group import read_science_data
 
 
-def _get_rgb_from_swir1_nir_vis(ds: xr.Dataset) -> np.ndarray:
+def _get_rgb_from_swir1_nir_vis(
+    ds: xr.Dataset,
+    swir1_var: str = "swir1",
+    nir_var: str = "nir",
+    vis_var: str = "vis",
+) -> np.ndarray:
     get_min_max = lambda x: np.array([ds[x].quantile(0.01), ds[x].quantile(0.99)])
 
-    r_min, r_max = get_min_max("swir1")
-    g_min, g_max = get_min_max("nir")
-    b_min, b_max = get_min_max("vis")
+    r_min, r_max = get_min_max(swir1_var)
+    g_min, g_max = get_min_max(nir_var)
+    b_min, b_max = get_min_max(vis_var)
 
     r_w, g_w, b_w = [1.0, 1.0, 1.0]
     r_s, g_s, b_s = [1.0, 1.0, 1.0]
@@ -34,9 +42,9 @@ def _get_rgb_from_swir1_nir_vis(ds: xr.Dataset) -> np.ndarray:
         _w * (ds[x] - _min) / (_s * (_max - _min)), a_min=0, a_max=1
     ).T
 
-    r_v = get_v("swir1", r_w, r_s, r_min, r_max)
-    g_v = get_v("nir", g_w, g_s, g_min, g_max)
-    b_v = get_v("vis", b_w, b_s, b_min, b_max)
+    r_v = get_v(swir1_var, r_w, r_s, r_min, r_max)
+    g_v = get_v(nir_var, g_w, g_s, g_min, g_max)
+    b_v = get_v(vis_var, b_w, b_s, b_min, b_max)
 
     rgb = np.stack((r_v, g_v, b_v), axis=2)
     rgb[np.isnan(rgb)] = 0.0
@@ -44,13 +52,26 @@ def _get_rgb_from_swir1_nir_vis(ds: xr.Dataset) -> np.ndarray:
     return rgb
 
 
-def _add_rgb(ds: xr.Dataset) -> xr.Dataset:
-    rgb = _get_rgb_from_swir1_nir_vis(ds)
-    # rgb = np.reshape(rgb, (rgb.shape[1], rgb.shape[0], 3))
+def _add_rgb(
+    ds: xr.Dataset,
+    swir1_var: str = "swir1",
+    nir_var: str = "nir",
+    vis_var: str = "vis",
+    rgb_var: str = "rgb",
+    rgb_dim: str = "rgb_channel",
+    along_track_dim: str = "along_track",
+    across_track_dim: str = "across_track",
+) -> xr.Dataset:
+    rgb = _get_rgb_from_swir1_nir_vis(
+        ds,
+        swir1_var=swir1_var,
+        nir_var=nir_var,
+        vis_var=vis_var,
+    )
 
-    ds["rgb"] = (("across_track", "along_track", "rgb_color"), rgb)
-    ds["rgb"].attrs["units"] = ""
-    ds["rgb"].attrs["long_name"] = "False RGB image"
+    ds[rgb_var] = ((across_track_dim, along_track_dim, rgb_dim), rgb)
+    ds[rgb_var].attrs["units"] = ""
+    ds[rgb_var].attrs["long_name"] = "False RGB image"
 
     return ds
 
@@ -80,13 +101,27 @@ def read_product_mrgr(
     modify: bool = DEFAULT_READ_EC_PRODUCT_MODIFY,
     header: bool = DEFAULT_READ_EC_PRODUCT_HEADER,
     meta: bool = DEFAULT_READ_EC_PRODUCT_META,
+    ensure_nans: bool = DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
+    **kwargs,
 ) -> xr.Dataset:
     """Opens MSI_RGR_1C file as a `xarray.Dataset`."""
-    ds = read_science_data(filepath, agency=FileAgency.ESA)
+    ds = read_science_data(
+        filepath,
+        agency=FileAgency.ESA,
+        ensure_nans=ensure_nans,
+        **kwargs,
+    )
 
     if not modify:
         return ds
 
+    ds = drop_samples_with_missing_geo_data_along_track(
+        ds=ds,
+        swath_lat_var="latitude",
+        along_track_dim="along_track",
+        across_track_dim="across_track",
+    )
+
     ds = ds.assign(
         vis=ds["pixel_values"].isel({"band": 0}),
         nir=ds["pixel_values"].isel({"band": 1}),
@@ -196,22 +231,22 @@ def read_product_mrgr(
 
     ds = _add_rgb(ds)
 
-    nadir_idx = get_nadir_index(ds)
-    print(nadir_idx)
-    ds = ds.rename({"latitude": "swath_latitude"})
-    ds = ds.rename({"longitude": "swath_longitude"})
+    nadir_idx = get_nadir_index(ds, nadir_idx=270)
+
+    ds = ds.rename({"latitude": SWATH_LAT_VAR})
+    ds = ds.rename({"longitude": SWATH_LON_VAR})
     ds = add_nadir_track(
         ds,
         nadir_idx,
-        swath_lat_var="swath_latitude",
-        swath_lon_var="swath_longitude",
+        swath_lat_var=SWATH_LAT_VAR,
+        swath_lon_var=SWATH_LON_VAR,
         along_track_dim="along_track",
         across_track_dim="across_track",
         nadir_lat_var="latitude",
         nadir_lon_var="longitude",
     )
     ds = add_across_track_distance(
-        ds, nadir_idx, swath_lat_var="swath_latitude", swath_lon_var="swath_longitude"
+        ds, nadir_idx, swath_lat_var=SWATH_LAT_VAR, swath_lon_var=SWATH_LON_VAR
     )
 
     ds = rename_common_dims_and_vars(
@@ -220,11 +255,11 @@ def read_product_mrgr(
         across_track_dim="across_track",
         track_lat_var="latitude",
         track_lon_var="longitude",
-        swath_lat_var="swath_latitude",
-        swath_lon_var="swath_longitude",
+        swath_lat_var=SWATH_LAT_VAR,
+        swath_lon_var=SWATH_LON_VAR,
         time_var="time",
     )
 
-    ds = add_header_and_meta_data(filepath=filepath, ds=ds, header=header, meta=meta)
+    ds = ds.reset_coords()
 
     return ds
