@@ -1,6 +1,7 @@
 import xarray as xr
 
 from ....constants import (
+    DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
     DEFAULT_READ_EC_PRODUCT_HEADER,
     DEFAULT_READ_EC_PRODUCT_META,
     DEFAULT_READ_EC_PRODUCT_MODIFY,
@@ -8,7 +9,6 @@ from ....constants import (
 from ....xarray_utils import merge_datasets
 from .._rename_dataset_content import rename_common_dims_and_vars
 from ..file_info import FileAgency
-from ..header_group import add_header_and_meta_data
 from ..science_group import read_science_data
 
 
@@ -17,9 +17,16 @@ def read_product_acth(
     modify: bool = DEFAULT_READ_EC_PRODUCT_MODIFY,
     header: bool = DEFAULT_READ_EC_PRODUCT_HEADER,
     meta: bool = DEFAULT_READ_EC_PRODUCT_META,
+    ensure_nans: bool = DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
+    **kwargs,
 ) -> xr.Dataset:
     """Opens ATL_CTH_2A file as a `xarray.Dataset`."""
-    ds = read_science_data(filepath, agency=FileAgency.ESA)
+    ds = read_science_data(
+        filepath,
+        agency=FileAgency.ESA,
+        ensure_nans=ensure_nans,
+        **kwargs,
+    )
 
     if not modify:
         return ds
@@ -32,6 +39,4 @@ def read_product_acth(
         time_var="time",
     )
 
-    ds = add_header_and_meta_data(filepath=filepath, ds=ds, header=header, meta=meta)
-
     return ds
