@@ -1,6 +1,7 @@
 import xarray as xr
 
 from ....constants import (
+    DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
     DEFAULT_READ_EC_PRODUCT_HEADER,
     DEFAULT_READ_EC_PRODUCT_META,
     DEFAULT_READ_EC_PRODUCT_MODIFY,
@@ -13,7 +14,6 @@ from .._rename_dataset_content import (
     rename_var_info,
 )
 from ..file_info import FileAgency
-from ..header_group import add_header_and_meta_data
 from ..science_group import read_science_data
 
 
@@ -22,9 +22,16 @@ def read_product_cfmr(
     modify: bool = DEFAULT_READ_EC_PRODUCT_MODIFY,
     header: bool = DEFAULT_READ_EC_PRODUCT_HEADER,
     meta: bool = DEFAULT_READ_EC_PRODUCT_META,
+    ensure_nans: bool = DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
+    **kwargs,
 ) -> xr.Dataset:
     """Opens CPR_FMR_2A file as a `xarray.Dataset`."""
-    ds = read_science_data(filepath, agency=FileAgency.ESA)
+    ds = read_science_data(
+        filepath,
+        agency=FileAgency.ESA,
+        ensure_nans=ensure_nans,
+        **kwargs,
+    )
 
     if not modify:
         return ds
@@ -40,6 +47,36 @@ def read_product_cfmr(
         elevation_var="surface_elevation",
     )
 
-    ds = add_header_and_meta_data(filepath=filepath, ds=ds, header=header, meta=meta)
+    ds = rename_var_info(
+        ds,
+        "reflectivity_no_attenuation_correction",
+        long_name="Atten. reflectivity factor",
+    )
+    ds = rename_var_info(
+        ds,
+        "reflectivity_masked",
+        long_name="Reflectivity masked",
+    )
+    ds = rename_var_info(
+        ds,
+        "reflectivity_corrected",
+        long_name="Reflectivity corrected",
+        units="dBz",
+    )
+    ds = rename_var_info(
+        ds,
+        "path_integrated_attenuation",
+        long_name="PIA",
+    )
+    ds = rename_var_info(
+        ds,
+        "brightness_temperature",
+        long_name="BT at 94 GHz",
+    )
+    ds = rename_var_info(
+        ds,
+        "detection_status",
+        long_name="Detection status",
+    )
 
     return ds
