@@ -1,6 +1,7 @@
 import xarray as xr
 
 from ....constants import (
+    DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
     DEFAULT_READ_EC_PRODUCT_HEADER,
     DEFAULT_READ_EC_PRODUCT_META,
     DEFAULT_READ_EC_PRODUCT_MODIFY,
@@ -13,7 +14,6 @@ from .._rename_dataset_content import (
     rename_var_info,
 )
 from ..file_info import FileAgency
-from ..header_group import add_header_and_meta_data
 from ..science_group import read_science_data
 
 
@@ -22,9 +22,16 @@ def read_product_ctc(
     modify: bool = DEFAULT_READ_EC_PRODUCT_MODIFY,
     header: bool = DEFAULT_READ_EC_PRODUCT_HEADER,
     meta: bool = DEFAULT_READ_EC_PRODUCT_META,
+    ensure_nans: bool = DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
+    **kwargs,
 ) -> xr.Dataset:
     """Opens CPR_TC__2A file as a `xarray.Dataset`."""
-    ds = read_science_data(filepath, agency=FileAgency.ESA)
+    ds = read_science_data(
+        filepath,
+        agency=FileAgency.ESA,
+        ensure_nans=ensure_nans,
+        **kwargs,
+    )
 
     if not modify:
         return ds
@@ -40,6 +47,4 @@ def read_product_ctc(
         elevation_var="surface_elevation",
     )
 
-    ds = add_header_and_meta_data(filepath=filepath, ds=ds, header=header, meta=meta)
-
     return ds
