@@ -2,21 +2,24 @@ import numpy as np
 import xarray as xr
 
 from ....constants import (
+    DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
     DEFAULT_READ_EC_PRODUCT_HEADER,
     DEFAULT_READ_EC_PRODUCT_META,
     DEFAULT_READ_EC_PRODUCT_MODIFY,
+    SWATH_LAT_VAR,
+    SWATH_LON_VAR,
     UNITS_KELVIN,
     UNITS_MSI_RADIANCE,
 )
 from ....swath_data.across_track_distance import (
     add_across_track_distance,
     add_nadir_track,
+    drop_samples_with_missing_geo_data_along_track,
     get_nadir_index,
 )
 from ....xarray_utils import merge_datasets
 from .._rename_dataset_content import rename_common_dims_and_vars, rename_var_info
 from ..file_info import FileAgency
-from ..header_group import add_header_and_meta_data
 from ..science_group import read_science_data
 
 
@@ -25,28 +28,42 @@ def read_product_mcm(
     modify: bool = DEFAULT_READ_EC_PRODUCT_MODIFY,
     header: bool = DEFAULT_READ_EC_PRODUCT_HEADER,
     meta: bool = DEFAULT_READ_EC_PRODUCT_META,
+    ensure_nans: bool = DEFAULT_READ_EC_PRODUCT_ENSURE_NANS,
+    **kwargs,
 ) -> xr.Dataset:
     """Opens MSI_CM__2A file as a `xarray.Dataset`."""
-    ds = read_science_data(filepath, agency=FileAgency.ESA)
+    ds = read_science_data(
+        filepath,
+        agency=FileAgency.ESA,
+        ensure_nans=ensure_nans,
+        **kwargs,
+    )
 
     if not modify:
         return ds
 
-    nadir_idx = get_nadir_index(ds, nadir_idx=278)
-    ds = ds.rename({"latitude": "swath_latitude"})
-    ds = ds.rename({"longitude": "swath_longitude"})
+    ds = drop_samples_with_missing_geo_data_along_track(
+        ds=ds,
+        swath_lat_var="latitude",
+        along_track_dim="along_track",
+        across_track_dim="across_track",
+    )
+
+    nadir_idx = get_nadir_index(ds, nadir_idx=266)
+    ds = ds.rename({"latitude": SWATH_LAT_VAR})
+    ds = ds.rename({"longitude": SWATH_LON_VAR})
     ds = add_nadir_track(
         ds,
         nadir_idx,
-        swath_lat_var="swath_latitude",
-        swath_lon_var="swath_longitude",
+        swath_lat_var=SWATH_LAT_VAR,
+        swath_lon_var=SWATH_LON_VAR,
         along_track_dim="along_track",
         across_track_dim="across_track",
         nadir_lat_var="latitude",
         nadir_lon_var="longitude",
     )
     ds = add_across_track_distance(
-        ds, nadir_idx, swath_lat_var="swath_latitude", swath_lon_var="swath_longitude"
+        ds, nadir_idx, swath_lat_var=SWATH_LAT_VAR, swath_lon_var=SWATH_LON_VAR
     )
 
     ds = rename_common_dims_and_vars(
@@ -55,11 +72,9 @@ def read_product_mcm(
         across_track_dim="across_track",
         track_lat_var="latitude",
         track_lon_var="longitude",
-        swath_lat_var="swath_latitude",
-        swath_lon_var="swath_longitude",
+        swath_lat_var=SWATH_LAT_VAR,
+        swath_lon_var=SWATH_LON_VAR,
         time_var="time",
     )
 
-    ds = add_header_and_meta_data(filepath=filepath, ds=ds, header=header, meta=meta)
-
     return ds
