@@ -3,6 +3,6 @@ from .delete import remove_dims
 from .exception import EmptyFilterResultError
 from .filter_latitude import filter_latitude
 from .filter_radius import filter_radius
-from .filter_time import filter_time
+from .filter_time import filter_time, get_filter_time_mask
 from .merge import merge_datasets
 from .scalars import convert_scalar_var_to_str
